@@ -10,6 +10,7 @@ from maleo.types.base.uuid import OptionalUUID
 from maleo.dtos.authentication import AuthenticationT
 from maleo.dtos.contexts.operation import OperationContext
 from maleo.dtos.contexts.request import RequestContext
+from maleo.dtos.contexts.response import ResponseContext
 from maleo.dtos.contexts.service import ServiceContext
 from maleo.dtos.error import (
     ErrorT,
@@ -44,7 +45,18 @@ from maleo.dtos.error.spec import (
     BadGatewayErrorSpec,
     ServiceUnavailableErrorSpec,
 )
+from maleo.schemas.operation.request import (
+    CreateFailedRequestOperation,
+    ReadFailedRequestOperation,
+    UpdateFailedRequestOperation,
+    DeleteFailedRequestOperation,
+    generate_failed_request_operation,
+)
 from maleo.schemas.operation.resource import (
+    CreateResourceOperationAction,
+    ReadResourceOperationAction,
+    UpdateResourceOperationAction,
+    DeleteResourceOperationAction,
     AllResourceOperationAction,
     CreateFailedResourceOperation,
     ReadFailedResourceOperation,
@@ -96,9 +108,10 @@ class MaleoException(
         operation_timestamp: Optional[OperationTimestamp] = None,
         operation_summary: str = "Request operation failed due to exception being raised",
         operation_action: AllResourceOperationAction,
-        request_context: Optional[RequestContext] = None,
-        authentication: AuthenticationT = None,
+        request_context: RequestContext,
+        authentication: AuthenticationT,
         details: OptionalAny = None,
+        response_context: Optional[ResponseContext] = None,
         response: Optional[ErrorResponseT] = None,
     ) -> None: ...
     @overload
@@ -148,10 +161,13 @@ class MaleoException(
         authentication: AuthenticationT = None,
         resource: Optional[Resource] = None,
         details: OptionalAny = None,
+        response_context: Optional[ResponseContext] = None,
         response: Optional[ErrorResponseT] = None,
     ) -> None:
         super().__init__(*args)
 
+        self.operation_type = operation_type
+
         self.service_context = (
             service_context
             if service_context is not None
@@ -173,6 +189,7 @@ class MaleoException(
         self.operation_action = operation_action
         self.resource = resource
         self.details = details
+        self.response_context = response_context
         self._response = response
 
     @property
@@ -206,17 +223,56 @@ class MaleoException(
         # * field's being already given a default value
         return self.response_cls(other=self.details)  # type: ignore
 
-    @property
-    def operation(
-        self,
+    @overload
+    def generate_operation(
+        self, operation_type: Literal[OperationType.REQUEST]
     ) -> Union[
+        CreateFailedRequestOperation[ErrorT, AuthenticationT, ErrorResponseT],
+        ReadFailedRequestOperation[ErrorT, AuthenticationT, ErrorResponseT],
+        UpdateFailedRequestOperation[ErrorT, AuthenticationT, ErrorResponseT],
+        DeleteFailedRequestOperation[ErrorT, AuthenticationT, ErrorResponseT],
+    ]: ...
+    @overload
+    def generate_operation(
+        self, operation_type: Literal[OperationType.RESOURCE]
+    ) -> Union[
+        CreateFailedResourceOperation[ErrorT, AuthenticationT, ErrorResponseT],
+        ReadFailedResourceOperation[ErrorT, AuthenticationT, ErrorResponseT],
+        UpdateFailedResourceOperation[ErrorT, AuthenticationT, ErrorResponseT],
+        DeleteFailedResourceOperation[ErrorT, AuthenticationT, ErrorResponseT],
+    ]: ...
+    @overload
+    def generate_operation(
+        self, operation_type: Literal[OperationType.SYSTEM]
+    ) -> FailedSystemOperation[ErrorT, AuthenticationT, ErrorResponseT]: ...
+    def generate_operation(self, operation_type: OperationType) -> Union[
+        CreateFailedRequestOperation[ErrorT, AuthenticationT, ErrorResponseT],
+        ReadFailedRequestOperation[ErrorT, AuthenticationT, ErrorResponseT],
+        UpdateFailedRequestOperation[ErrorT, AuthenticationT, ErrorResponseT],
+        DeleteFailedRequestOperation[ErrorT, AuthenticationT, ErrorResponseT],
         CreateFailedResourceOperation[ErrorT, AuthenticationT, ErrorResponseT],
         ReadFailedResourceOperation[ErrorT, AuthenticationT, ErrorResponseT],
         UpdateFailedResourceOperation[ErrorT, AuthenticationT, ErrorResponseT],
         DeleteFailedResourceOperation[ErrorT, AuthenticationT, ErrorResponseT],
         FailedSystemOperation[ErrorT, AuthenticationT, ErrorResponseT],
     ]:
-        if isinstance(self.operation_action, SystemOperationAction):
+        if operation_type != self.operation_type:
+            raise ValueError(
+                ErrorCode.INTERNAL_SERVER_ERROR,
+                f"Mismatched 'operation_type': '{self.operation_type}'",
+            )
+
+        if self.operation_type not in OperationType:
+            raise ValueError(
+                ErrorCode.INTERNAL_SERVER_ERROR,
+                f"Invalid 'operation_type': '{self.operation_type}'",
+            )
+
+        if self.operation_type is OperationType.SYSTEM:
+            if not isinstance(self.operation_action, SystemOperationAction):
+                raise TypeError(
+                    f"Invalid type for 'operation_action': {type(self.operation_action)}"
+                )
             return FailedSystemOperation[ErrorT, AuthenticationT, ErrorResponseT](
                 service_context=self.service_context,
                 id=self.operation_id,
@@ -229,12 +285,55 @@ class MaleoException(
                 action=self.operation_action,
                 response=self.response,
             )
-        else:
+
+        elif self.operation_type is OperationType.REQUEST:
+            if not isinstance(
+                self.operation_action,
+                (
+                    CreateResourceOperationAction,
+                    ReadResourceOperationAction,
+                    UpdateResourceOperationAction,
+                    DeleteResourceOperationAction,
+                ),
+            ):
+                raise TypeError(
+                    f"Invalid type for 'operation_action': {type(self.operation_action)}"
+                )
+
+            return generate_failed_request_operation(
+                action=self.operation_action,
+                service_context=self.service_context,
+                id=self.operation_id,
+                context=self.operation_context,
+                timestamp=self.operation_timestamp,
+                summary=self.operation_summary,
+                error=self.error,
+                request_context=self.request_context,
+                authentication=self.authentication,
+                response_context=self.response_context,
+                response=self.response,
+            )
+
+        elif self.operation_type is OperationType.RESOURCE:
+            if not isinstance(
+                self.operation_action,
+                (
+                    CreateResourceOperationAction,
+                    ReadResourceOperationAction,
+                    UpdateResourceOperationAction,
+                    DeleteResourceOperationAction,
+                ),
+            ):
+                raise TypeError(
+                    f"Invalid type for 'operation_action': {type(self.operation_action)}"
+                )
+
             if self.resource is None:
                 raise ValueError(
                     ErrorCode.INTERNAL_SERVER_ERROR,
                     "Resource must be given for resource operation exception",
                 )
+
             return generate_failed_resource_operation(
                 action=self.operation_action,
                 service_context=self.service_context,
@@ -249,6 +348,13 @@ class MaleoException(
                 response=self.response,
             )
 
+        else:
+            # This should never happen due to the first check, but makes the function exhaustive
+            raise ValueError(
+                ErrorCode.INTERNAL_SERVER_ERROR,
+                f"Unhandled operation_type: '{self.operation_type}'",
+            )
+
 
 class ClientException(
     MaleoException[
