@@ -8,10 +8,17 @@ from starlette.exceptions import HTTPException as StarletteHTTPException
 from typing import List, Type, Union
 from maleo.constants.error import ERROR_STATUS_CODE_MAP
 from maleo.dtos.authentication import AuthenticationT
+from maleo.dtos.contexts.response import ResponseContext
 from maleo.dtos.error.spec import ErrorSpecT
 from maleo.dtos.error import ErrorT
 from maleo.enums.error import Code as ErrorCode
 from maleo.logging.enums import Level, LoggerType
+from maleo.schemas.operation.request import (
+    CreateFailedRequestOperation,
+    ReadFailedRequestOperation,
+    UpdateFailedRequestOperation,
+    DeleteFailedRequestOperation,
+)
 from maleo.schemas.response import (
     ErrorResponse,
     ErrorResponseT,
@@ -127,8 +134,27 @@ async def maleo_exception_handler(
         f"{exc.service_context.environment} - {exc.service_context.key} - {LoggerType.EXCEPTION}"
     )
 
-    exc.operation.log(logger, level=Level.ERROR)
-    return JSONResponse(
+    operation = exc.generate_operation(exc.operation_type)
+
+    final_response = JSONResponse(
         content=exc.response.model_dump(mode="json"),
         status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
     )
+
+    if isinstance(
+        operation,
+        (
+            CreateFailedRequestOperation,
+            ReadFailedRequestOperation,
+            UpdateFailedRequestOperation,
+            DeleteFailedRequestOperation,
+        ),
+    ):
+        response_context, final_response = await ResponseContext.async_from_response(
+            final_response
+        )
+        operation.response_context = response_context
+
+    operation.log(logger, level=Level.ERROR)
+
+    return final_response
